@@ -181,7 +181,7 @@ class CAM(object):
         now = datetime.datetime.utcnow()
         for node in node_list:
             dt = datetime.datetime.fromisoformat(node_list[node]['timestamp'])
-            if (now - dt).seconds > 60:
+            if (now - dt).seconds > 300:
                 self._redis.hdel("node_list", node)
         self._hset("node_list", get_node_name(), self._node_status)
 
@@ -216,7 +216,7 @@ class CAM(object):
                 return None
             if len_task_pending != 0 and not self._node_status["node_status"] in ["RUNNING", "WAIT RESOURCE", "WAIT LOCK"]:
                 node_list = self._get_hlist("node_list")
-                prior = [e for e in node_list if node_list[e]["node_status"] in ["IDLE", "FINISHED"] and node_list[e]["priority"] > self._node_status["priority"]]
+                prior = [e for e in node_list if node_list[e]["node_status"] in ["IDLE", "FINISHED"] and (node_list[e]["priority"] > self._node_status["priority"] or e > self._node_status["node"])]
                 if len(prior) > 0:
                     return None
                 task = self._redis.rpop("task_pending")
